deriva.transfer.download.processors package
===========================================

Subpackages
-----------

.. toctree::

    deriva.transfer.download.processors.postprocess
    deriva.transfer.download.processors.query
    deriva.transfer.download.processors.transform

Submodules
----------

deriva.transfer.download.processors.base\_processor module
----------------------------------------------------------

.. automodule:: deriva.transfer.download.processors.base_processor
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: deriva.transfer.download.processors
    :members:
    :undoc-members:
    :show-inheritance:
